// this file is public domain

#include <botan/config.h>
#include <string>
using namespace Botan;

struct algorithm
   {
      algorithm(const std::string& t, const std::string& n,
                u32bit k = 0, u32bit i = 0) :
         type(t), name(n), filtername(n), keylen(k), ivlen(i) {}
      algorithm(const std::string& t, const std::string& n,
                const std::string& f, u32bit k = 0, u32bit i = 0) :
         type(t), name(n), filtername(f), keylen(k), ivlen(i) {}
      std::string type, name, filtername;
      u32bit keylen, ivlen, weight;
   };

extern const std::string END = "END";

algorithm algorithms[] = {
   algorithm("Block Cipher", "Blowfish", 16),
   algorithm("Block Cipher", "CAST-256", 16),
   algorithm("Block Cipher", "CAST-128", "CAST5", 16),
   algorithm("Block Cipher", "CS-Cipher", 16),
   algorithm("Block Cipher", "DES", 8),
   algorithm("Block Cipher", "DESX", 24),
   algorithm("Block Cipher", "TripleDES", 24),
   algorithm("Block Cipher", "GOST", 32),
   algorithm("Block Cipher", "IDEA", 16),
   algorithm("Block Cipher", "Lion(MD5,ISAAC)", "Lion(MD5,ISAAC,65536)", 16),
   algorithm("Block Cipher", "Lion(SHA-1,SEAL)", "Lion(SHA-1,SEAL,65536)", 20),
   algorithm("Block Cipher", "Luby-Rackoff(SHA-1)", 16),
   algorithm("Block Cipher", "MARS", 32),
   algorithm("Block Cipher", "MISTY1", 16),
   algorithm("Block Cipher", "RC2", 16),
   algorithm("Block Cipher", "RC5(12)", 16),
   algorithm("Block Cipher", "RC5(16)", 16),
   algorithm("Block Cipher", "RC6", 32),
   algorithm("Block Cipher", "Rijndael [AES] (r=10)", "Rijndael", 16),
   algorithm("Block Cipher", "Rijndael [AES] (r=12)", "Rijndael", 24),
   algorithm("Block Cipher", "Rijndael [AES] (r=14)", "Rijndael", 32),
   algorithm("Block Cipher", "SAFER-SK(10)", 16),
   algorithm("Block Cipher", "Serpent", 32),
   algorithm("Block Cipher", "SHARK", 16),
   algorithm("Block Cipher", "Skipjack", 10),
   algorithm("Block Cipher", "Square", 16),
   algorithm("Block Cipher", "TEA", 16),
   algorithm("Block Cipher", "ThreeWay", 12),
   algorithm("Block Cipher", "Twofish", 32),
   algorithm("Block Cipher", "XTEA", 16),

   algorithm("Cipher Mode", "AES/CBC/PKCS7", 16, 16),
   algorithm("Cipher Mode", "AES/CBC/CTS", 16, 16),
   algorithm("Cipher Mode", "AES/CFB(128)", 16, 16),
   algorithm("Cipher Mode", "AES/CFB(64)", 16, 16),
   algorithm("Cipher Mode", "AES/CFB(32)", 16, 16),
   algorithm("Cipher Mode", "AES/CFB(16)", 16, 16),
   algorithm("Cipher Mode", "AES/CFB(8)", 16, 16),
   algorithm("Cipher Mode", "AES/OFB", 16, 16),
   algorithm("Cipher Mode", "AES/CTR", "AES/CTR-BE", 16, 16),

   algorithm("Stream Cipher", "ARC4", 16),
   algorithm("Stream Cipher", "ISAAC", 16),
   algorithm("Stream Cipher", "SEAL", "SEAL(8192)", 20),
   algorithm("Stream Cipher", "WiderWake4+1", "WiderWake4+1-BE", 16),

   algorithm("Hash", "Adler32"),
   algorithm("Hash", "CRC24"),
   algorithm("Hash", "CRC32"),
   algorithm("Hash", "HAS-160"),
   algorithm("Hash", "HAS-V"),
   algorithm("Hash", "HAVAL", "HAVAL(32)"),
   algorithm("Hash", "MD2"),
   algorithm("Hash", "MD4"),
   algorithm("Hash", "MD5"),
   algorithm("Hash", "RIPEMD-128"),
   algorithm("Hash", "RIPEMD-160"),
   algorithm("Hash", "SHA-160"),
   algorithm("Hash", "SHA-256"),
   algorithm("Hash", "SHA-384"),
   algorithm("Hash", "SHA-512"),
   algorithm("Hash", "Tiger"),
   algorithm("Hash", "Whirlpool"),

   algorithm("MAC", "EMAC(Square)", 16),
   algorithm("MAC", "HMAC(SHA-1)", 16),
   algorithm("MAC", "MD5-MAC", 16),
   algorithm("MAC", "X9.19-MAC", 16),

   algorithm("RNG", "Randpool"),
   algorithm("RNG", "X9.17(Rijndael)"),

   algorithm(END, END)
};
