/*************************************************
* BER Decoder Header File                        *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_BER_DECODER_H__
#define BOTAN_BER_DECODER_H__

#include <botan/base.h>
#include <botan/asn1_oid.h>
#include <botan/data_src.h>
#include <botan/bigint.h>

namespace Botan {

/*************************************************
* BER Encoded Object                             *
*************************************************/
struct BER_Object
   {
   ASN1_Tag tag;
   SecureVector<byte> value;
   };

/*************************************************
* BER Decoding Object                            *
*************************************************/
class BER_Decoder
   {
   public:
      void verify_end();
      SecureVector<byte> get_remaining();
      void discard_remaining();
      BER_Object get_next_object();
      BER_Decoder(DataSource&);
      BER_Decoder(const byte[], u32bit);
      BER_Decoder(const BER_Decoder&);
      ~BER_Decoder();
   private:
      BER_Decoder& operator=(const BER_Decoder&) { return (*this); }
      DataSource* source;
      mutable bool owns;
   };

/*************************************************
* BER Decoding Functions                         *
*************************************************/
namespace BER {

void decode_null(BER_Decoder&);
void decode(BER_Decoder&, bool&);
void decode(BER_Decoder&, u32bit&);
void decode(BER_Decoder&, BigInt&);
void decode(BER_Decoder&, SecureVector<byte>&, ASN1_Tag = OCTET_STRING);
void decode(BER_Decoder&, OID&);
BER_Decoder get_subsequence(BER_Decoder&);

}

}

#endif
