/*************************************************
* PBE Retrieval Source File                      *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#include <botan/lookup.h>
#include <botan/pbe_pkcs.h>

namespace Botan {

/*************************************************
* Get an PBE by name                             *
*************************************************/
PBE* get_pbe(const std::string& pbe_name, Cipher_Dir direction)
   {
   std::vector<std::string> algo_name;
   algo_name = parse_algorithm_name(deref_alias(pbe_name));

   if(algo_name.size() != 3)
      throw Invalid_Algorithm_Name(pbe_name);

   const std::string pbe = algo_name[0];
   const std::string digest = algo_name[1];
   const std::string cipher = algo_name[2];

   if(pbe == "PBE-PKCS5v15")
      return new PBE_PKCS5v15(digest, cipher, direction);
   else if(pbe == "PBE-PKCS5v20")
      return new PBE_PKCS5v20(digest, cipher, direction);
   throw Algorithm_Not_Found(pbe_name);
   }

}
