/*************************************************
* OID Registry Source File                       *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#include <botan/oids.h>
#include <botan/exceptn.h>
#include <map>

namespace Botan {

namespace OIDS {

namespace {

struct OID_Info
   {
   std::string name;
   };

std::map<OID, OID_Info> oid_registry;

}

/*************************************************
* Register an OID to string mapping              *
*************************************************/
void add_oid(const OID& oid, const std::string& name)
   {
   OID_Info new_oid_info = oid_registry[oid];
   if(new_oid_info.name != "" && new_oid_info.name != name)
      throw Exception("OIDS::add_oid: name conflict for " + oid.as_string() +
                      ": " + new_oid_info.name + " and " + name);
   new_oid_info.name = name;
   oid_registry[oid] = new_oid_info;
   }

/*************************************************
* Do a string to OID lookup                      *
*************************************************/
std::string identify_algorithm(const OID& oid)
   {
   std::map<OID, OID_Info>::const_iterator oid_info = oid_registry.find(oid);
   if(oid_info == oid_registry.end())
      return "";
   return oid_registry[oid].name;
   }

}

namespace {

/*************************************************
* OID loading helper function                    *
*************************************************/
void add_oid(const std::string& oid_str, const std::string& name)
   {
   OID oid(oid_str);
   OIDS::add_oid(oid, name);
   }

}

/*************************************************
* Load all of the default OIDs                   *
*************************************************/
void setup_oids()
   {
   add_oid("1.2.840.113549.1.1.1", "RSA");
   add_oid("2.5.8.1.1", "RSA");
   add_oid("1.2.840.10040.4.1", "DSA");
   add_oid("1.2.840.10046.2.1", "DH");
   }

}
